@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: generate_test_data.py 9694 2016-06-29 09:50:19Z Judy $
+# $Id: generate_test_data.py 10079 2017-07-03 13:52:00Z David $
 #
 # Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Judy $
-# $Date: 2016-06-29 17:50:19 +0800 (三, 29  6 2016) $
-# $Revision: 9694 $
+# $Author: David $
+# $Date: 2017-07-03 21:52:00 +0800 (Mon, 03 Jul 2017) $
+# $Revision: 10079 $
 
 import datetime
 import random
@@ -22,16 +22,10 @@ import string
 def createStatTestData(contactNum=100, testContactNum=5, testDays=15,
                        sent=90, error=10, invalid=5, opened=80, openedOnSite=30,
                        linkOpened=60, unsubscription=10, bounce=5, complain=5,
-                       reject=5, sendTest=90):
+                       rejected=5, sendTest=90):
     """
     Create statistic test data.
     
-    @param contactNum The amount of contact.
-                      The default value is 100.    
-    @param testContactNum The amount of test contact.
-                          The default value is 5.  
-    @param testDays The range of test day.
-                    The default value is 15.   
     @param sent The percentage of sent email.
                 The default value is 90.
                 NOTICE: 'sent' plus 'error' should equal to 100.
@@ -45,9 +39,9 @@ def createStatTestData(contactNum=100, testContactNum=5, testDays=15,
                   NOTICE: 'opened' include 'opened unique', 'opened on site' and 
                   'link opened', so 'opened' should bigger than 'opened on site'
                   and 'link opened'.           
-    @param openedOnSite The percentage of email opened on site.
+    @param opened_on_site The percentage of email opened on site.
                           The default value is 30.
-    @param linkOpened The percentage of link opened email.
+    @param link_opened The percentage of link opened email.
                        The default value is 60.
     @param unsubscription The percentage of unsubscribe email.
                           The default value is 10.
@@ -256,7 +250,7 @@ def createStatTestData(contactNum=100, testContactNum=5, testDays=15,
         time = time.strftime(timeStringFormat)
         _contact = validContacts[i]
         createContactStatus(
-            newsletter, _contact, ContactMailingStatus.BOUNCE, time)
+            newsletter, _contact, ContactMailingStatus.BOUNCED, time)
         bounceContact.append(_contact)
     
     for i in range(complainNum):
@@ -264,7 +258,7 @@ def createStatTestData(contactNum=100, testContactNum=5, testDays=15,
         time = time.strftime(timeStringFormat)
         _contact = validContacts[i + bounceNum-1]
         createContactStatus(
-            newsletter, _contact, ContactMailingStatus.COMPLAIN, time)
+            newsletter, _contact, ContactMailingStatus.COMPLAINT, time)
         complainContact.append(_contact)
     
     for i in range(rejectNum):
@@ -272,7 +266,7 @@ def createStatTestData(contactNum=100, testContactNum=5, testDays=15,
         time = time.strftime(timeStringFormat)
         _contact = validContacts[i + bounceNum-1 + complainNum - 1]
         createContactStatus(
-            newsletter, _contact, ContactMailingStatus.REJECT, time)
+            newsletter, _contact, ContactMailingStatus.REJECTED, time)
         rejectContact.append(_contact)
         
     # send test
@@ -295,7 +289,7 @@ class Command(BaseCommand):
     named 'test.json'. You can setting option argument to create your own test
     data as well.
     
-    A test server can be run with the test data we just created by doing
+    A test server can be run with the test data we just created by using
     following steps:
     
     1) Add a folder called 'fixture' in any app in your project.
@@ -303,12 +297,11 @@ class Command(BaseCommand):
     3) Copy 'initial_data.json' from demo project into 'fixture'
     4) Run command 
        python manage.py testserver --addrport='YOURPORT' initial_data 'TESTDATA'
-       TESTDATA would be the file name of test data. Then, a test server will 
-       start.
+       TESTDATA would be the file name of test data.
        example: python manage.py testserver --addrport=7788 test initial_data
+    5) Then a test server will start.
     
-    See more on related ticket: 
-    https://code.nuwainfo.com/trac/mercurius/ticket/2741
+    Related ticket: https://code.nuwainfo.com/trac/mercurius/ticket/2741
     
     @param contact_num The Amount of contact for testing.
                        The default is 100.
@@ -456,7 +449,7 @@ class Command(BaseCommand):
         _reject = int(options['reject'])
         _sendTest = int(options['sendTest'])
         
-        if options['randomData'] == True:
+        if options['randomData'] == 'T':
             _sent = random.randint(80, 100)
             _error = 100 - _sent
             _invalid = random.randint(0, int(_sent/4))
